@@ -1,6 +1,7 @@
-import { V1ObjectMeta } from '@kubernetes/client-node'
-import { listNamespacedResources } from '../lib/resource-request'
-import { IResource } from './resource'
+/* Copyright Contributors to the Open Cluster Management project */
+
+import { V1ObjectMeta } from '@kubernetes/client-node/dist/gen/model/v1ObjectMeta'
+import { IResource, IResourceDefinition } from './resource'
 
 export const ManagedClusterAddOnApiVersion = 'addon.open-cluster-management.io/v1alpha1'
 export type ManagedClusterAddOnApiVersionType = 'addon.open-cluster-management.io/v1alpha1'
@@ -8,6 +9,11 @@ export type ManagedClusterAddOnApiVersionType = 'addon.open-cluster-management.i
 export const ManagedClusterAddOnKind = 'ManagedClusterAddOn'
 export type ManagedClusterAddOnKindType = 'ManagedClusterAddOn'
 
+export const ManagedClusterAddOnDefinition: IResourceDefinition = {
+    apiVersion: ManagedClusterAddOnApiVersion,
+    kind: ManagedClusterAddOnKind,
+}
+
 export interface ManagedClusterAddOn extends IResource {
     apiVersion: ManagedClusterAddOnApiVersionType
     kind: ManagedClusterAddOnKindType
@@ -15,9 +21,9 @@ export interface ManagedClusterAddOn extends IResource {
     spec: {}
     status?: {
         conditions: {
-            lastTransitionTime: string
-            message: string
-            reason: string
+            lastTransitionTime?: string
+            message?: string
+            reason?: string
             status: string
             type: string
         }[]
@@ -31,11 +37,3 @@ export interface ManagedClusterAddOn extends IResource {
         }
     }
 }
-
-export function listManagedClusterAddOns(namespace: string) {
-    return listNamespacedResources<ManagedClusterAddOn>({
-        apiVersion: ManagedClusterAddOnApiVersion,
-        kind: ManagedClusterAddOnKind,
-        metadata: { namespace },
-    })
-}
