@@ -793,6 +793,10 @@ module.exports = {
 	"11.4.7": "87.0.4280.141",
 	"11.4.8": "87.0.4280.141",
 	"11.4.9": "87.0.4280.141",
+	"11.4.10": "87.0.4280.141",
+	"11.4.11": "87.0.4280.141",
+	"11.4.12": "87.0.4280.141",
+	"11.5.0": "87.0.4280.141",
 	"12.0.0-beta.1": "89.0.4328.0",
 	"12.0.0-beta.3": "89.0.4328.0",
 	"12.0.0-beta.4": "89.0.4328.0",
@@ -856,6 +860,17 @@ module.exports = {
 	"12.0.11": "89.0.4389.128",
 	"12.0.12": "89.0.4389.128",
 	"12.0.13": "89.0.4389.128",
+	"12.0.14": "89.0.4389.128",
+	"12.0.15": "89.0.4389.128",
+	"12.0.16": "89.0.4389.128",
+	"12.0.17": "89.0.4389.128",
+	"12.0.18": "89.0.4389.128",
+	"12.1.0": "89.0.4389.128",
+	"12.1.1": "89.0.4389.128",
+	"12.1.2": "89.0.4389.128",
+	"12.2.0": "89.0.4389.128",
+	"12.2.1": "89.0.4389.128",
+	"12.2.2": "89.0.4389.128",
 	"13.0.0-beta.2": "90.0.4402.0",
 	"13.0.0-beta.3": "90.0.4402.0",
 	"13.0.0-beta.4": "90.0.4415.0",
@@ -939,6 +954,20 @@ module.exports = {
 	"13.1.4": "91.0.4472.106",
 	"13.1.5": "91.0.4472.124",
 	"13.1.6": "91.0.4472.124",
+	"13.1.7": "91.0.4472.124",
+	"13.1.8": "91.0.4472.164",
+	"13.1.9": "91.0.4472.164",
+	"13.2.0": "91.0.4472.164",
+	"13.2.1": "91.0.4472.164",
+	"13.2.2": "91.0.4472.164",
+	"13.2.3": "91.0.4472.164",
+	"13.3.0": "91.0.4472.164",
+	"13.4.0": "91.0.4472.164",
+	"13.5.0": "91.0.4472.164",
+	"13.5.1": "91.0.4472.164",
+	"13.5.2": "91.0.4472.164",
+	"13.6.0": "91.0.4472.164",
+	"13.6.1": "91.0.4472.164",
 	"14.0.0-beta.1": "92.0.4511.0",
 	"14.0.0-beta.2": "92.0.4511.0",
 	"14.0.0-beta.3": "92.0.4511.0",
@@ -950,6 +979,19 @@ module.exports = {
 	"14.0.0-beta.10": "93.0.4539.0",
 	"14.0.0-beta.11": "93.0.4557.4",
 	"14.0.0-beta.12": "93.0.4557.4",
+	"14.0.0-beta.13": "93.0.4566.0",
+	"14.0.0-beta.14": "93.0.4566.0",
+	"14.0.0-beta.15": "93.0.4566.0",
+	"14.0.0-beta.16": "93.0.4566.0",
+	"14.0.0-beta.17": "93.0.4566.0",
+	"14.0.0-beta.18": "93.0.4577.15",
+	"14.0.0-beta.19": "93.0.4577.15",
+	"14.0.0-beta.20": "93.0.4577.15",
+	"14.0.0-beta.21": "93.0.4577.15",
+	"14.0.0-beta.22": "93.0.4577.25",
+	"14.0.0-beta.23": "93.0.4577.25",
+	"14.0.0-beta.24": "93.0.4577.51",
+	"14.0.0-beta.25": "93.0.4577.51",
 	"14.0.0-nightly.20210304": "90.0.4402.0",
 	"14.0.0-nightly.20210305": "90.0.4415.0",
 	"14.0.0-nightly.20210308": "90.0.4415.0",
@@ -992,6 +1034,29 @@ module.exports = {
 	"14.0.0-nightly.20210520": "92.0.4511.0",
 	"14.0.0-nightly.20210523": "92.0.4511.0",
 	"14.0.0-nightly.20210524": "92.0.4511.0",
+	"14.0.0": "93.0.4577.58",
+	"14.0.1": "93.0.4577.63",
+	"14.0.2": "93.0.4577.82",
+	"14.1.0": "93.0.4577.82",
+	"14.1.1": "93.0.4577.82",
+	"14.2.0": "93.0.4577.82",
+	"15.0.0-alpha.1": "93.0.4566.0",
+	"15.0.0-alpha.2": "93.0.4566.0",
+	"15.0.0-alpha.3": "94.0.4584.0",
+	"15.0.0-alpha.4": "94.0.4584.0",
+	"15.0.0-alpha.5": "94.0.4584.0",
+	"15.0.0-alpha.6": "94.0.4584.0",
+	"15.0.0-alpha.7": "94.0.4590.2",
+	"15.0.0-alpha.8": "94.0.4590.2",
+	"15.0.0-alpha.9": "94.0.4590.2",
+	"15.0.0-alpha.10": "94.0.4606.12",
+	"15.0.0-beta.1": "94.0.4606.20",
+	"15.0.0-beta.2": "94.0.4606.20",
+	"15.0.0-beta.3": "94.0.4606.31",
+	"15.0.0-beta.4": "94.0.4606.31",
+	"15.0.0-beta.5": "94.0.4606.31",
+	"15.0.0-beta.6": "94.0.4606.31",
+	"15.0.0-beta.7": "94.0.4606.31",
 	"15.0.0-nightly.20210527": "92.0.4511.0",
 	"15.0.0-nightly.20210528": "92.0.4511.0",
 	"15.0.0-nightly.20210531": "92.0.4511.0",
@@ -1018,5 +1083,108 @@ module.exports = {
 	"15.0.0-nightly.20210630": "93.0.4558.0",
 	"15.0.0-nightly.20210701": "93.0.4558.0",
 	"15.0.0-nightly.20210702": "93.0.4558.0",
-	"15.0.0-nightly.20210705": "93.0.4558.0"
+	"15.0.0-nightly.20210705": "93.0.4558.0",
+	"15.0.0-nightly.20210706": "93.0.4566.0",
+	"15.0.0-nightly.20210707": "93.0.4566.0",
+	"15.0.0-nightly.20210708": "93.0.4566.0",
+	"15.0.0-nightly.20210709": "93.0.4566.0",
+	"15.0.0-nightly.20210712": "93.0.4566.0",
+	"15.0.0-nightly.20210713": "93.0.4566.0",
+	"15.0.0-nightly.20210714": "93.0.4566.0",
+	"15.0.0-nightly.20210715": "93.0.4566.0",
+	"15.0.0-nightly.20210716": "93.0.4566.0",
+	"15.0.0-nightly.20210719": "93.0.4566.0",
+	"15.0.0-nightly.20210720": "93.0.4566.0",
+	"15.0.0-nightly.20210721": "93.0.4566.0",
+	"15.0.0": "94.0.4606.51",
+	"15.1.0": "94.0.4606.61",
+	"15.1.1": "94.0.4606.61",
+	"15.1.2": "94.0.4606.71",
+	"15.2.0": "94.0.4606.81",
+	"15.3.0": "94.0.4606.81",
+	"16.0.0-alpha.1": "95.0.4629.0",
+	"16.0.0-alpha.2": "95.0.4629.0",
+	"16.0.0-alpha.3": "95.0.4629.0",
+	"16.0.0-alpha.4": "95.0.4629.0",
+	"16.0.0-alpha.5": "95.0.4629.0",
+	"16.0.0-alpha.6": "95.0.4629.0",
+	"16.0.0-alpha.7": "95.0.4629.0",
+	"16.0.0-alpha.8": "96.0.4647.0",
+	"16.0.0-alpha.9": "96.0.4647.0",
+	"16.0.0-beta.1": "96.0.4647.0",
+	"16.0.0-beta.2": "96.0.4647.0",
+	"16.0.0-beta.3": "96.0.4647.0",
+	"16.0.0-beta.4": "96.0.4664.18",
+	"16.0.0-beta.5": "96.0.4664.18",
+	"16.0.0-nightly.20210722": "93.0.4566.0",
+	"16.0.0-nightly.20210723": "93.0.4566.0",
+	"16.0.0-nightly.20210726": "93.0.4566.0",
+	"16.0.0-nightly.20210727": "94.0.4584.0",
+	"16.0.0-nightly.20210728": "94.0.4584.0",
+	"16.0.0-nightly.20210729": "94.0.4584.0",
+	"16.0.0-nightly.20210730": "94.0.4584.0",
+	"16.0.0-nightly.20210802": "94.0.4584.0",
+	"16.0.0-nightly.20210803": "94.0.4584.0",
+	"16.0.0-nightly.20210804": "94.0.4584.0",
+	"16.0.0-nightly.20210805": "94.0.4584.0",
+	"16.0.0-nightly.20210806": "94.0.4584.0",
+	"16.0.0-nightly.20210809": "94.0.4584.0",
+	"16.0.0-nightly.20210810": "94.0.4584.0",
+	"16.0.0-nightly.20210811": "94.0.4584.0",
+	"16.0.0-nightly.20210812": "94.0.4590.2",
+	"16.0.0-nightly.20210813": "94.0.4590.2",
+	"16.0.0-nightly.20210816": "94.0.4590.2",
+	"16.0.0-nightly.20210817": "94.0.4590.2",
+	"16.0.0-nightly.20210818": "94.0.4590.2",
+	"16.0.0-nightly.20210819": "94.0.4590.2",
+	"16.0.0-nightly.20210820": "94.0.4590.2",
+	"16.0.0-nightly.20210823": "94.0.4590.2",
+	"16.0.0-nightly.20210824": "95.0.4612.5",
+	"16.0.0-nightly.20210825": "95.0.4612.5",
+	"16.0.0-nightly.20210826": "95.0.4612.5",
+	"16.0.0-nightly.20210827": "95.0.4612.5",
+	"16.0.0-nightly.20210830": "95.0.4612.5",
+	"16.0.0-nightly.20210831": "95.0.4612.5",
+	"16.0.0-nightly.20210901": "95.0.4612.5",
+	"16.0.0-nightly.20210902": "95.0.4629.0",
+	"16.0.0-nightly.20210903": "95.0.4629.0",
+	"16.0.0-nightly.20210906": "95.0.4629.0",
+	"16.0.0-nightly.20210907": "95.0.4629.0",
+	"16.0.0-nightly.20210908": "95.0.4629.0",
+	"16.0.0-nightly.20210909": "95.0.4629.0",
+	"16.0.0-nightly.20210910": "95.0.4629.0",
+	"16.0.0-nightly.20210913": "95.0.4629.0",
+	"16.0.0-nightly.20210914": "95.0.4629.0",
+	"16.0.0-nightly.20210915": "95.0.4629.0",
+	"16.0.0-nightly.20210916": "95.0.4629.0",
+	"16.0.0-nightly.20210917": "95.0.4629.0",
+	"16.0.0-nightly.20210920": "95.0.4629.0",
+	"16.0.0-nightly.20210921": "95.0.4629.0",
+	"16.0.0-nightly.20210922": "95.0.4629.0",
+	"17.0.0-nightly.20210923": "95.0.4629.0",
+	"17.0.0-nightly.20210924": "95.0.4629.0",
+	"17.0.0-nightly.20210927": "95.0.4629.0",
+	"17.0.0-nightly.20210928": "95.0.4629.0",
+	"17.0.0-nightly.20210929": "95.0.4629.0",
+	"17.0.0-nightly.20210930": "95.0.4629.0",
+	"17.0.0-nightly.20211001": "95.0.4629.0",
+	"17.0.0-nightly.20211004": "95.0.4629.0",
+	"17.0.0-nightly.20211005": "95.0.4629.0",
+	"17.0.0-nightly.20211006": "96.0.4647.0",
+	"17.0.0-nightly.20211007": "96.0.4647.0",
+	"17.0.0-nightly.20211008": "96.0.4647.0",
+	"17.0.0-nightly.20211011": "96.0.4647.0",
+	"17.0.0-nightly.20211012": "96.0.4647.0",
+	"17.0.0-nightly.20211013": "96.0.4647.0",
+	"17.0.0-nightly.20211014": "96.0.4647.0",
+	"17.0.0-nightly.20211015": "96.0.4647.0",
+	"17.0.0-nightly.20211018": "96.0.4647.0",
+	"17.0.0-nightly.20211019": "96.0.4647.0",
+	"17.0.0-nightly.20211020": "96.0.4647.0",
+	"17.0.0-nightly.20211021": "96.0.4647.0",
+	"17.0.0-nightly.20211022": "96.0.4664.4",
+	"17.0.0-nightly.20211025": "96.0.4664.4",
+	"17.0.0-nightly.20211026": "96.0.4664.4",
+	"17.0.0-nightly.20211027": "96.0.4664.4",
+	"17.0.0-nightly.20211028": "96.0.4664.4"
 };
\ No newline at end of file
