@@ -22,7 +22,7 @@ setDefaults({
   throwHttpErrors: false,
 });
 
-module.exports = async function request(options, { mTLS = false, DPoP } = {}) {
+module.exports = async function request(options, { accessToken, mTLS = false, DPoP } = {}) {
   const { url } = options;
   isAbsoluteUrl(url);
   const optsFn = this[HTTP_OPTIONS];
@@ -33,7 +33,7 @@ module.exports = async function request(options, { mTLS = false, DPoP } = {}) {
     opts.headers.DPoP = this.dpopProof({
       htu: url,
       htm: options.method,
-    }, DPoP);
+    }, DPoP, accessToken);
   }
 
   if (optsFn) {
@@ -44,7 +44,7 @@ module.exports = async function request(options, { mTLS = false, DPoP } = {}) {
     mTLS
     && (
       (!opts.key || !opts.cert)
-      && (!opts.https || !opts.https.key || !opts.https.certificate)
+      && (!opts.https || !((opts.https.key && opts.https.certificate) || opts.https.pfx))
     )
   ) {
     throw new TypeError('mutual-TLS certificate and key not set');
